EXEC msdb.dbo.sp_delete_database_backuphistory @database_name=N'ITProject'
 Go
 USE [master]
 GO
 
 IF EXISTS (SELECT name FROM sys.databases WHERE name=N'ITProject')
	ALTER DATABASE ITProject SET SINGLE_USER WITH ROLLBACK IMMEDIATE
 GO
 
 USE [master]
 GO
 
 --usuwamy baze jesli istnieje
 IF EXISTS (SELECT name FROM sys.databases WHERE name=N'ITProject')
	DROP DATABASE ITProject
 GO
 
 USE [master]
 GO
 
 -- tworzenie bazy
 CREATE DATABASE ITProject
 GO
 
 USE ITProject
 GO
 --podstawowa tabela z uzytkownikami
 CREATE TABLE Users
 (
	id_users INT IDENTITY PRIMARY KEY,
	login VARCHAR(20) NOT NULL UNIQUE,
	password NVARCHAR(255) NOT NULL,
	first_name NVARCHAR(30) NOT NULL,
	last_name NVARCHAR(30) NOT NULL,
	date_of_birth DATE NOT NULL,-- check(date_of_birth<now()),
	email VARCHAR(30) NOT NULL UNIQUE CHECK(email LIKE '%@%.%'),
	state TINYINT default 2,
	role TINYINT default 1,
	date_of_register Datetime not null,
	last_visit datetime null, -- jak rejestrujemy to jeszcze nie byl tylko sie zarejestrowal
	sex char(1) not null
 )
 
 -- stan uzytkownika
 CREATE TABLE UserState
 (
	id_userState TINYINT PRIMARY KEY,
	name VARCHAR(30) NOT NULL UNIQUE
 )
 GO
 
 INSERT INTO UserState VALUES(1,'Active')
 INSERT INTO UserState VALUES(2,'Inactive')
 INSERT INTO UserState VALUES(3,'Banned')
 GO
 
 -- rola izytkownika
 CREATE TABLE UserRole
 (
	id_userRole TINYINT PRIMARY KEY,
	name VARCHAR(30) NOT NULL UNIQUE
 )
 GO
 -- status do uzytkownikow ogolny i projektowy
 INSERT INTO UserRole VALUES(1,'User')
  --zaklada projekt
 INSERT INTO UserRole VALUES(2,'Administrator')
-- moze dodawac releasy itp
 INSERT INTO UserRole VALUES(3,'Moderator')
 GO

 -- klucze obce do uzytkownikow 
 ALTER TABLE Users ADD CONSTRAINT fk1 FOREIGN KEY(state) REFERENCES UserState
 ALTER TABLE Users ADD CONSTRAINT fk2 FOREIGN KEY(role) REFERENCES UserRole
 GO

-- gowna tabela projektu
 CREATE Table Project
 (
	id_project INT IDENTITY PRIMARY KEY,
	name varchar(30) not null UNIQUE,
	short_description VARCHAR(80) not null,
	start_date DATE not null, -- data zalozenia projektu
	long_description varchar(MAX) not null, --description to chyba nie moze byc
	logo varchar(255) null, -- trzymamy sciezke do pliku na serwerze
	id_owner INT FOREIGN KEY REFERENCES USERS NOT NULL -- identyfikator waciciela projektu
 )
--aczenie uzytkownika z projektem
 Create table ProjectUser
 (
	id_project int foreign key references Project NOT NULL,
	id_user int foreign key references Users NOT NULL,
	id_role tinyint foreign key references UserRole default 1 NOT NULL,
	PRIMARY KEY(id_project,id_user)
 )
 
 create table Profil
 (
	id_user int foreign key references Users NOT NULL,
	avatar varchar(255) null,
	interest varchar(MAX) null,
	about varchar(MAX) null,
	experience varchar(MAX) null,
	skills varchar(MAX) null,
	country varchar(20) null,
	city varchar(30) null
 )
 
 Create table ActivationHash
 (
	id int,
	[hash] varchar(15),
	primary key(id,[hash])
 )

 --tabela do tworzenia wiadomoci
 CREATE TABLE Message
 (
	id_message INT IDENTITY PRIMARY KEY,
	date_of_send DATETIME NOT NULL,
	subject VARCHAR(50) NOT NULL,
	text VARCHAR(MAX) NOT NULL,
	readed BIT NOT NULL DEFAULT 0,
	read_confirmation BIT NOT NULL DEFAULT 0,
	id_sender INT FOREIGN KEY REFERENCES Users(id_users) NOT NULL,
	id_receive INT FOREIGN KEY REFERENCES Users(id_users) NOT NULL  
 )

 CREATE TABLE Team
 (
	id_team INT IDENTITY PRIMARY KEY,
	name VARCHAR(30) NOT NULL,
	descript VARCHAR(MAX) NULL,
	date_of_create DATETIME NOT NULL,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL,
	id_leader INT FOREIGN KEY REFERENCES Users NOT NULL
 )

 -- tabela czca zesp z uczestnikami
 CREATE TABLE TeamUser
 (
	id_team INT FOREIGN KEY REFERENCES Team NOT NULL,
	id_user INT FOREIGN KEY REFERENCES Users NOT NULL,
	PRIMARY KEY(id_team,id_user)
 )

 --tabela z zaproszeniami
 CREATE TABLE Invitation
 (
	id_user INT FOREIGN KEY REFERENCES Users NOT NULL,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL,
	date_of_invitation DATETIME NOT NULL,
	PRIMARY KEY(id_user,id_project)
 )

 -------------------------------------------------------
 ----------------- NOWOCI W BAZIE ---------------------

 -- tabela odpowiadajaca za status zadania, releasu etc.
 CREATE TABLE StatusTable
 (
	id_status TINYINT PRIMARY KEY,
	name VARCHAR(30) NOT NULL UNIQUE,
 )
 -- uzupelnienie tabeli Status
  INSERT INTO StatusTable VALUES(1,'Planned')
  INSERT INTO StatusTable VALUES(2,'Active')
  INSERT INTO StatusTable VALUES(3,'Done')
  INSERT INTO StatusTable VALUES(4,'Accepted')

  -- tabela odpowiadajaca za zmiane statusu zadania
  CREATE TABLE StatusChange
  (
	id_status_change INT IDENTITY PRIMARY KEY,
	id_user INT FOREIGN KEY REFERENCES USERS NOT NULL, -- identyfikator uytkownika zmieniajcego status
	date_of_change DATETIME NOT NULL,
	comment VARCHAR(255),
	id_old_status TINYINT FOREIGN KEY REFERENCES StatusTable NULL,
	id_new_status TINYINT FOREIGN KEY REFERENCES StatusTable NOT NULL,
  )

  CREATE TABLE Priority
  (
	id_priority TINYINT PRIMARY KEY,
	name VARCHAR(30) NOT NULL UNIQUE
  )

  INSERT INTO Priority VALUES(1,'Low')
  INSERT INTO Priority VALUES(2,'Normal')
  INSERT INTO Priority VALUES(3,'High')

  CREATE TABLE Release 
  (
	id_release INT IDENTITY PRIMARY KEY,
	name VARCHAR(30) NOT NULL,
	descript VARCHAR(MAX),
	planned_stop_date DATE NOT NULL,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL,
	id_status TINYINT FOREIGN KEY REFERENCES StatusTable NOT NULL
  )

  -- powizanie zmian statusu z konkretnym releasem
  CREATE TABLE ReleaseStatusChange
  (
	id_release INT FOREIGN KEY REFERENCES Release NOT NULL,
	id_status_change INT FOREIGN KEY REFERENCES StatusChange NOT NULL,
	PRIMARY KEY(id_release,id_status_change)
  )

  CREATE TABLE Feature
  (
	id_feature INT IDENTITY PRIMARY KEY,
	name VARCHAR(50) NOT NULL,
	descript VARCHAR(MAX),
	start_date DATETIME NOT NULL,
	planned_stop_date DATE NOT NULL,
	id_status TINYINT FOREIGN KEY REFERENCES StatusTable NOT NULL,
	id_priority TINYINT FOREIGN KEY REFERENCES PRIORITY NOT NULL,
	is_to_team BIT NOT NULL, -- 0 - fasz, czyli jest do usera, 1 - prawda, jest feture jest do teamu
	id_release INT FOREIGN KEY REFERENCES Release NULL,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL
  )

  -- polaczenie funkcjonalnosci z uytkownikiem ktry ma j wykona
  CREATE TABLE FeatureUser
  (
	id_feature INT FOREIGN KEY REFERENCES Feature NOT NULL,
	id_user INT FOREIGN KEY REFERENCES Users NOT NULL,
	PRIMARY KEY(id_feature, id_user)
  )

   -- polaczenie funkcjonalnosci z zespoem ktry ma j wykona
  CREATE TABLE FeatureTeam
  (
	id_feature INT FOREIGN KEY REFERENCES Feature NOT NULL,
	id_team INT FOREIGN KEY REFERENCES Team NOT NULL 
	PRIMARY KEY(id_feature, id_team)
  )

   CREATE TABLE FeatureStatusChange
  (
	id_feature INT FOREIGN KEY REFERENCES Feature NOT NULL,
	id_status_change INT FOREIGN KEY REFERENCES StatusChange NOT NULL,
	PRIMARY KEY(id_feature,id_status_change)
  )

  CREATE TABLE FunctionalRequirement
  (
	id_requirement INT IDENTITY PRIMARY KEY,
	name VARCHAR(50) NOT NULL,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL,
	actors VARCHAR(255) NULL,
	id_priority TINYINT FOREIGN KEY REFERENCES Priority NOT NULL,
	id_author INT FOREIGN KEY REFERENCES Users NOT NULL,
	date_of_create DATETIME NOT NULL,
	date_of_last_modification DATETIME NOT NULL,
	descript VARCHAR(MAX) NULL, 
	init_conditions VARCHAR(255) NULL,
	final_conditions VARCHAR(255) NULL
  )

  -- powiazanie funcjonalnosci z wymaganiami funckjonalnymi
  -- prawdopodobnie nie bedzie uzywane
  --CREATE TABLE FeatureFunctionalRequirement
  -- (
  --	id_requirement INT FOREIGN KEY REFERENCES FunctionalRequirement NOT NULL,
  --	id_feature INT FOREIGN KEY REFERENCES Feature NOT NULL
  --  )

  CREATE TABLE Scenario
  (
    id_scenario INT PRIMARY KEY,
	number INT NOT NULL,
	id_requirement INT FOREIGN KEY REFERENCES FunctionalRequirement NOT NULL,
	id_scenario_parent INT FOREIGN KEY REFERENCES Scenario NULL,
	scenario_text VARCHAR(MAX) NOT NULL
  )

  Create table SVNHistory
  (
	Id			int		primary key identity,
	ProjectId   int		foreign key references Project,
	UserId		int		foreign key references Users,
	CreateDate	datetime not null,
	[Type]		int		 not null,
	[Description] nvarchar(MAX),
	[Filename]	nvarchar(MAX) 
  )

  CREATE TABLE ForumTopic
  (
	Id int Primary key identity,
	Topic nvarchar(50) not null,
	AddDate datetime not null,
	AutorId int foreign key references Users,
	ProjectId int foreign key references Project
  )

  Create table Post
  (
		
		Id int Primary key identity,
		AutorId int foreign key references Users,
		TopicId int foreign key references ForumTopic,
		AddDate datetime not null,
		Content nvarchar(MAX) not null
  )


  -- obsuga taskw

  CREATE TABLE Task
  (
	id INT IDENTITY PRIMARY KEY,
	id_project INT FOREIGN KEY REFERENCES Project NOT NULL,
	id_user INT FOREIGN KEY REFERENCES Users NOT NULL,
	id_feature INT FOREIGN KEY REFERENCES Feature NULL,
	name VARCHAR(50) NOT NULL,
	descript VARCHAR(MAX),
	start_date DATETIME NOT NULL,
	planned_stop_date DATE NOT NULL,
	id_status TINYINT FOREIGN KEY REFERENCES StatusTable NOT NULL,
	id_priority TINYINT FOREIGN KEY REFERENCES PRIORITY NOT NULL,
  )

  CREATE TABLE TaskStatusChange
  (
	id_task INT FOREIGN KEY REFERENCES Task NOT NULL,
	id_status_change INT FOREIGN KEY REFERENCES StatusChange NOT NULL,
	PRIMARY KEY(id_task,id_status_change)
  )
  
  --- komentarze do projektu
  
  Create table Comment
  (
		id_comment int identity primary key ,
		id_project int foreign key references Project not null,
		id_user int foreign key references Users not null,
		Ctext varchar(MAX) not null,
		CDateTime datetime not null
  ) 
  
